### Have Ideas or Requests?

Got a great idea for a Font Awesome goodie or shirt? Don't see your favorite icon in a wear-able or share-able format?

We're all ears! Spend a few minutes and let us know what you'd want. If we end up using your idea, we'll send you a free copy.

Make a Store Suggestion!

Please note: While we appreciate all suggestions, not every idea might be right for Font Awesome nor could we physically make every idea.